@@ -17,10 +17,13 @@ class ClassShexer(object):
                  disable_comments=False, namespaces_dict=None, tolerance_to_keep_similar_rules=0,
                  allow_opt_cardinality=True, disable_exact_cardinality=False,
                  shapes_namespace=SHAPES_DEFAULT_NAMESPACE, inverse_paths=False,
-                 decimals=-1, instances_report_mode=RATIO_INSTANCES):
+                 decimals=-1, instances_report_mode=RATIO_INSTANCES, detect_minimal_iri=False,
+                 class_min_iris_dict=None):
         self._class_counts_dict = class_counts_dict
         self._class_profile_dict = class_profile_dict if class_profile_dict is not None else self._load_class_profile_dict_from_file(
             class_profile_json_file)
+        self._class_min_iris_dict = class_min_iris_dict
+
         self._shapes_list = []
         self._remove_empty_shapes = remove_empty_shapes
         self._all_compliant_mode = all_compliant_mode
@@ -36,6 +39,7 @@ class ClassShexer(object):
         self._shapes_namespace = shapes_namespace
         self._decimals = decimals
         self._instances_report_mode = instances_report_mode
+        self._detect_minimal_iri = detect_minimal_iri
 
         self._original_target_nodes = determine_original_target_nodes_if_needed(remove_empty_shapes=remove_empty_shapes,
                                                                                 original_target_classes=original_target_classes,
