@@ -37,7 +37,8 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                          shapes_namespace=SHAPES_DEFAULT_NAMESPACE,
                          limit_remote_instances=-1,
                          inverse_paths=False,
-                         compression_mode=None
+                         compression_mode=None,
+                         disable_endpoint_cache=False
                          ):
     """
 
@@ -95,7 +96,8 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                                               limit_remote_instances=limit_remote_instances,
                                               inverse_paths=inverse_paths,
                                               all_classes_mode=all_classes_mode,
-                                              compression_mode=compression_mode
+                                              compression_mode=compression_mode,
+                                              disable_endpoint_cache=disable_endpoint_cache
                                               )
     else:
         instance_yielder = get_triple_yielder(source_file=graph_file_input,
@@ -122,7 +124,8 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                                               limit_remote_instances=limit_remote_instances,
                                               inverse_paths=inverse_paths,
                                               all_classes_mode=all_classes_mode,
-                                              compression_mode=compression_mode
+                                              compression_mode=compression_mode,
+                                              disable_endpoint_cache=disable_endpoint_cache
                                               )
 
     selectors_tracker = None
@@ -134,7 +137,8 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                                       graph_file_input=graph_file_input,
                                       url_input=url_input,
                                       graph_format=input_format,
-                                      built_remote_graph=built_remote_graph)
+                                      built_remote_graph=built_remote_graph,
+                                      disable_endpoint_cache=disable_endpoint_cache)
         valid_shape_map = built_shape_map
         if built_shape_map is None:
             shape_map_parser = get_shape_map_parser(format=shape_map_format,
@@ -165,9 +169,11 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
     return _decide_tracker_to_return(selectors_tracker, pure_instances_tracker)
 
 
-def _get_adequate_sgraph(endpoint_url, graph_file_input, url_input, graph_format, raw_graph, built_remote_graph):
+def _get_adequate_sgraph(endpoint_url, graph_file_input, url_input, graph_format,
+                         raw_graph, built_remote_graph, disable_endpoint_cache):
     if endpoint_url is not None:
-        return built_remote_graph if built_remote_graph is not None else EndpointSGraph(endpoint_url=endpoint_url)
+        return built_remote_graph if built_remote_graph is not None else EndpointSGraph(endpoint_url=endpoint_url,
+                                                                                        store_locally=not disable_endpoint_cache)
     else:
         return RdflibSgraph(source_file=graph_file_input if graph_file_input is not None else url_input,
                             raw_graph=raw_graph,
